@@ -152,12 +152,14 @@ public class SimpleDaemon implements Daemon, Runnable, DaemonUserSignal {
     }
 
     private void checkForReload() {
-      if (this.softReloadSignalled) {
-        System.err.println("SimpleDaemon: picked up reload, waiting for connections to finish...");
-        while (! this.handlers.isEmpty()) {}
-        System.err.println("SimpleDaemon: all connections have finished, pretending to reload");
-        this.softReloadSignalled = false;
-      }
+        if (this.softReloadSignalled) {
+            System.err.println("SimpleDaemon: picked up reload, waiting for connections to finish...");
+            while (!this.handlers.isEmpty()) {
+                // noop
+            }
+            System.err.println("SimpleDaemon: all connections have finished, pretending to reload");
+            this.softReloadSignalled = false;
+        }
     }
 
     protected void addHandler(final Handler handler) {
@@ -261,7 +263,7 @@ public class SimpleDaemon implements Daemon, Runnable, DaemonUserSignal {
                         case -1:
                             return;
 
-                        /* Attempt to shutdown */
+                        /* Attempt to shut down */
                         case '1':
                             out.println("Attempting a shutdown...");
                             try {
